import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeTableau10,
} from 'd3';

const svg = select("svg");
const width = window.innerWidth;
const height = window.innerHeight;

// dollors 
const numberFormat = number =>
  	(Math.abs(Number(number))) ;


const render = data => {
  const pieData = pie().sort(null).value(d=>d.total_medals)(data);
  const colors = scaleOrdinal(schemeTableau10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(180)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.total_medals))
  	.on("mouseover", d => console.log(d.data.total_medals));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });

  legend.append("rect").attr("width",22).attr("height",25).attr("x", 38)
  	.attr("y", -30)
  	.attr("fill", d => colors(d.data.total_medals));
  legend.append("text")
  	.attr("x", 68)
  	.attr("y", -10)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  legend.append("text")
  	.attr("x", 300)
  	.attr("y", -10)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.total_medals));
}


const csvUrl =
 'https://gist.githubusercontent.com/Jasvitha/06dfbf4e124d3d85274f7b1bb00f80de/raw/c24c17558d2d68d9a941b5501cc233ec5a13c5c2/Baby_names.csv';


//Load the data and display basic cost of netflix 
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.total_medals-data1.total_medals);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});